@@ -1,19 +1,18 @@
 use std::{
-    fs,
     io::{self, Write},
     lazy::SyncOnceCell,
     path::Path,
-    process::{Child, Command},
+    process::{Child, Command, Stdio},
     sync::Arc,
 };
 
 #[derive(Clone, Debug, Default)]
-pub struct TransparentRunnerInner(Arc<SyncOnceCell<tempfile::TempPath>>);
+pub struct TransparentRunnerImpl(Arc<SyncOnceCell<tempfile::TempPath>>);
 
-impl TransparentRunnerInner {
+impl TransparentRunnerImpl {
     fn write_runner_executable_to_disk() -> io::Result<tempfile::TempPath> {
         #[cfg(feature = "__docs_rs")]
-        unreachable!();
+        let bytes = &[];
         #[cfg(not(feature = "__docs_rs"))]
         let bytes = include_bytes!(concat!(env!("OUT_DIR"), "\\virtual-desktop-runner.exe"));
         let mut file = tempfile::Builder::new()
@@ -31,13 +30,16 @@ impl TransparentRunnerInner {
     }
 
     pub fn spawn_transparent(&self, command: &Command) -> io::Result<Child> {
-        let runner_path = dbg!(self.get_runner_executable_path()?);
+        let runner_path = self.get_runner_executable_path()?;
 
         let mut runner_command = Command::new(runner_path);
         runner_command
-            .arg(fs::canonicalize(command.get_program())?)
+            .arg(command.get_program())
             .arg("--")
-            .args(command.get_args());
+            .args(command.get_args())
+            .stdin(Stdio::piped())
+            .stdout(Stdio::piped())
+            .stderr(Stdio::piped());
 
         for env in command.get_envs() {
             match env {
@@ -46,8 +48,10 @@ impl TransparentRunnerInner {
             };
         }
 
-        if let Some(current_dir) = command.get_current_dir() {
-            runner_command.current_dir(current_dir);
+        if let Some(cd) = command.get_current_dir() {
+            runner_command.current_dir(cd);
+        } else {
+            runner_command.current_dir(std::env::current_dir()?);
         }
 
         runner_command.spawn()
